@@ -3,19 +3,18 @@
  * Copyright (C) 2004 Francis James Franklin
  * 
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 2.1
  * of the License, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
- * 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along along with this program; if not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -302,20 +301,15 @@ static EnchantDict * appleSpell_provider_request_dict (EnchantProvider * me, con
 	@autoreleasepool {
 		// NSLog (@"appleSpell_provider_request_dict");
 		AppleSpellChecker * checker = static_cast<AppleSpellChecker *>(me->user_data);
-		EnchantDict * dict = g_new0 (EnchantDict, 1);
 
-		if (!me || !tag || !checker || !dict)
+		if (!me || !tag || !checker)
 			{
 				return 0;
 			}
 
-		dict->check            = appleSpell_dict_check;
-		dict->suggest          = appleSpell_dict_suggest;
-
 		AppleSpellDictionary * ASD = g_new0 (AppleSpellDictionary, 1);
 		if (!ASD)
 			{
-				g_free (dict);
 				return 0;
 			}
 
@@ -325,13 +319,23 @@ static EnchantDict * appleSpell_provider_request_dict (EnchantProvider * me, con
 		if (!ASD->DictionaryName)
 			{
 				g_free (ASD);
-				g_free (dict);
 				return 0;
 			}
 
 		[ASD->DictionaryName retain];
 		// NSLog (@"appleSpell_provider_request_dict: providing dictionary \"%@\"", ASD->DictionaryName);
+
+		EnchantDict * dict = enchant_broker_new_dict (me->owner);
+
+		if (!dict)
+			{
+				return 0;
+			}
+
+		dict->check     = appleSpell_dict_check;
+		dict->suggest   = appleSpell_dict_suggest;
 		dict->user_data = (void *) ASD;
+
 		return dict;
 	}
 }
@@ -349,7 +353,6 @@ static void appleSpell_provider_dispose_dict (EnchantProvider * me, EnchantDict
 						[ASD->DictionaryName release];
 						g_free (ASD);
 					}
-				g_free (dict);
 			}
 	}
 }
@@ -396,8 +399,6 @@ static void appleSpell_provider_dispose (EnchantProvider * me)
 				AppleSpellChecker * checker = static_cast<AppleSpellChecker *>(me->user_data);
 				if (checker)
 					delete checker;
-
-				g_free (me);
 			}
 	}
 }
@@ -418,7 +419,7 @@ extern "C" {
 		@autoreleasepool {
 			// NSLog (@"init_enchant_provider");
 
-			EnchantProvider * provider = g_new0 (EnchantProvider, 1);
+			EnchantProvider * provider = enchant_provider_new ();
 			if (!provider)
 				{
 					return 0;
